% Auto-generated chapter 8 for nasai
% Hadiths in this chapter: 54

\hadithdefcmd{nasai}{688}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ بَحِيرٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ كَثِيرِ بْنِ مُرَّةَ، عَنْ عَمْرِو بْنِ عَبَسَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ بَنَى مَسْجِدًا يُذْكَرُ اللَّهُ فِيهِ بَنَى اللَّهُ عَزَّ وَجَلَّ لَهُ بَيْتًا فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{688}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Amr bin 'Abasah that the Messenger of Allah (ﷺ) said:"Whoever builds a Masjid in which Allah is remembered, Allah, (the Mighty and Sublime) will build for him a house in Paradise}}
\hadithdefcmd{nasai}{689}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مِنْ أَشْرَاطِ السَّاعَةِ أَنْ يَتَبَاهَى النَّاسُ فِي الْمَسَاجِدِ ‏"‏ ‏.‏\hadithno{689}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas that the Prophet (ﷺ) said:"One of the portents of the Hour will be that people will show off in building Masjids}}
\hadithdefcmd{nasai}{690}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، قَالَ كُنْتُ أَقْرَأُ عَلَى أَبِي الْقُرْآنَ فِي السِّكَّةِ فَإِذَا قَرَأْتُ السَّجْدَةَ سَجَدَ فَقُلْتُ يَا أَبَتِ أَتَسْجُدُ فِي الطَّرِيقِ فَقَالَ إِنِّي سَمِعْتُ أَبَا ذَرٍّ يَقُولُ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَىُّ مَسْجِدٍ وُضِعَ أَوَّلاً قَالَ ‏"‏ الْمَسْجِدُ الْحَرَامُ ‏"‏ ‏.‏ قُلْتُ ثُمَّ أَىُّ قَالَ ‏"‏ الْمَسْجِدُ الأَقْصَى ‏"‏ ‏.‏ قُلْتُ وَكَمْ بَيْنَهُمَا قَالَ ‏"‏ أَرْبَعُونَ عَامًا وَالأَرْضُ لَكَ مَسْجِدٌ فَحَيْثُمَا أَدْرَكْتَ الصَّلاَةَ فَصَلِّ ‏"‏ ‏.‏\hadithno{690}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibrahim said:"I used to recite Qur'an to my father on the road, and if I recited a verse in which prostration was required, he would prostrate. I said: 'O my father, do you prostrate on the street?' He said: 'I heard Abu Dharr say: "I asked the Messenger of Allah (ﷺ): 'Which Masjid was built first?' He said: 'Al-Masjid Al-Haram.' [1] I said: 'Then which?' He said: 'Al-Masjid Al-Aqsa.' [2] I said: 'How long was there between them?' He said: 'Forty years. And the earth is a Masjid (or a place of prostration) for you, so wherever you are when the time for prayer comes, pray.'" [1] In Makkah. [2] "Furthest Masjid", meaning the Masjid in Jerulsalem}}
\hadithdefcmd{nasai}{691}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ مَعْبَدِ بْنِ عَبَّاسٍ، أَنَّ مَيْمُونَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ مَنْ صَلَّى فِي مَسْجِدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الصَّلاَةُ فِيهِ أَفْضَلُ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ إِلاَّ مَسْجِدَ الْكَعْبَةِ ‏"‏ ‏.‏\hadithno{691}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that Maimunah the wife of the Prophet (ﷺ) said:"Whoever prays in the Masjid of the Messenger of Allah (ﷺ) (that is good), for I heard the Messenger of Allah (ﷺ) say: ' One prayer offered there is better than a thousand prayers offered elsewhere, except the Masjid of the Ka'bah}}
\hadithdefcmd{nasai}{692}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْبَيْتَ هُوَ وَأُسَامَةُ بْنُ زَيْدٍ وَبِلاَلٌ وَعُثْمَانُ بْنُ طَلْحَةَ فَأَغْلَقُوا عَلَيْهِمْ فَلَمَّا فَتَحَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم كُنْتُ أَوَّلَ مَنْ وَلَجَ فَلَقِيتُ بِلاَلاً فَسَأَلْتُهُ هَلْ صَلَّى فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ صَلَّى بَيْنَ الْعَمُودَيْنِ الْيَمَانِيَيْنِ ‏.‏\hadithno{692}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim that his father said:"The Messenger of Allah (ﷺ) entered the House (the Ka'bah), with Usamah bin Zaid, Bilal and 'Uthman bin Talhah, and they locked the door behind them. When the Messenger of Allah (ﷺ) opened it, I was the first one to enter. I met Bilal and asked him: 'Did the Messenger of Allah (ﷺ) pray inside?' He said: 'Yes, he prayed between the two Yemeni columns}}
\hadithdefcmd{nasai}{693}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو مُسْهِرٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنِ ابْنِ الدَّيْلَمِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَّ سُلَيْمَانَ بْنَ دَاوُدَ صلى الله عليه وسلم لَمَّا بَنَى بَيْتَ الْمَقْدِسِ سَأَلَ اللَّهَ عَزَّ وَجَلَّ خِلاَلاً ثَلاَثَةً سَأَلَ اللَّهَ عَزَّ وَجَلَّ حُكْمًا يُصَادِفُ حُكْمَهُ فَأُوتِيَهُ وَسَأَلَ اللَّهَ عَزَّ وَجَلَّ مُلْكًا لاَ يَنْبَغِي لأَحَدٍ مِنْ بَعْدِهِ فَأُوتِيَهُ وَسَأَلَ اللَّهَ عَزَّ وَجَلَّ حِينَ فَرَغَ مِنْ بِنَاءِ الْمَسْجِدِ أَنْ لاَ يَأْتِيَهُ أَحَدٌ لاَ يَنْهَزُهُ إِلاَّ الصَّلاَةُ فِيهِ أَنْ يُخْرِجَهُ مِنْ خَطِيئَتِهِ كَيَوْمِ وَلَدَتْهُ أُمُّهُ ‏"‏ ‏.‏\hadithno{693}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that the Messenger of Allah (ﷺ) said:"When Sulaiman bin Dawud finished building Bait Al-Maqdis, he asked Allah for three things: Judgement that was in harmony with His judgement, and he was given that. And he asked Allah for a dominion that no one after him would have, and he was given that. And when he finished building the Masjid he asked Allah, the Mighty and Sublime, that no one should come to it, intending only to pray there, but he would emerge free of sin as the day his mother bore him}}
\hadithdefcmd{nasai}{694}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَأَبِي عَبْدِ اللَّهِ الأَغَرِّ، مَوْلَى الْجُهَنِيِّينَ وَكَانَا مِنْ أَصْحَابِ أَبِي هُرَيْرَةَ أَنَّهُمَا سَمِعَا أَبَا هُرَيْرَةَ يَقُولُ صَلاَةٌ فِي مَسْجِدِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَفْضَلُ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ مِنَ الْمَسَاجِدِ إِلاَّ الْمَسْجِدَ الْحَرَامَ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم آخِرُ الأَنْبِيَاءِ وَمَسْجِدُهُ آخِرُ الْمَسَاجِدِ ‏.‏ قَالَ أَبُو سَلَمَةَ وَأَبُو عَبْدِ اللَّهِ لَمْ نَشُكَّ أَنَّ أَبَا هُرَيْرَةَ كَانَ يَقُولُ عَنْ حَدِيثِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمُنِعْنَا أَنْ نَسْتَثْبِتَ أَبَا هُرَيْرَةَ فِي ذَلِكَ الْحَدِيثِ حَتَّى إِذَا تُوُفِّيَ أَبُو هُرَيْرَةَ ذَكَرْنَا ذَلِكَ وَتَلاَوَمْنَا أَنْ لاَ نَكُونَ كَلَّمْنَا أَبَا هُرَيْرَةَ فِي ذَلِكَ حَتَّى يُسْنِدَهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم إِنْ كَانَ سَمِعَهُ مِنْهُ فَبَيْنَا نَحْنُ عَلَى ذَلِكَ جَالَسْنَا عَبْدَ اللَّهِ بْنَ إِبْرَاهِيمَ بْنِ قَارِظٍ فَذَكَرْنَا ذَلِكَ الْحَدِيثَ وَالَّذِي فَرَّطْنَا فِيهِ مِنْ نَصِّ أَبِي هُرَيْرَةَ فَقَالَ لَنَا عَبْدُ اللَّهِ بْنُ إِبْرَاهِيمَ أَشْهَدُ أَنِّي سَمِعْتُ أَبَا هُرَيْرَةَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَإِنِّي آخِرُ الأَنْبِيَاءِ وَإِنَّهُ آخِرُ الْمَسَاجِدِ ‏"‏ ‏.‏\hadithno{694}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Salamah bin 'Abdur-Rahman and Abu 'Abdullah Al-Agharr, the freed slave of the Juhanis - better of whom were companions of Abu Hurairah - that they heard Abu Hurairah say:"One prayer in the Masjid of the Messenger of Allah (ﷺ) is better than one thousand prayers offered in other mosques, except Al-Masjid Al-Haram, for the Messenger of Allah (ﷺ) was the last of the prophets and his Masjid was the last of the Masjids." Abu Salamah and Abu 'Abdullah said: "We do not doubt that Abu Hurairah was speaking on the basis of the Hadith of the Messenger of Allah (ﷺ), but we could not verify that Hadith with Abu Hurairah before he died. Then we remembered that and we blamed one another for not having spoken to Abu Hurairah about that, so that he could attribute it to the Messenger of Allah (ﷺ) if he had indeed heard it from him. While we were arguing, we went and sat down with 'Abdullah bin Ibrahim bin Qariz, and we told him about the Hadith and how we had been negligent in not checking it with Abu Hurairah. 'Abdullah bin Ibrahim said to us: 'I bear witness that I heard Abu Hurairah say: The Messenger of Allah (ﷺ) said: I am the last of the prophets and it is the last of the Masjids}}
\hadithdefcmd{nasai}{695}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا بَيْنَ بَيْتِي وَمِنْبَرِي رَوْضَةٌ مِنْ رِيَاضِ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{695}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Zaid said:"The Messenger of Allah (ﷺ) said: 'The area between my house and my Minbar is one of the gardens of Paradise}}
\hadithdefcmd{nasai}{696}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمَّارٍ الدُّهْنِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ قَوَائِمَ مِنْبَرِي هَذَا رَوَاتِبُ فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{696}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Umm Salamah that the Prophet (ﷺ) said:"The columns of this Minbar of mine will be in Paradise}}
\hadithdefcmd{nasai}{697}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عِمْرَانَ بْنِ أَبِي أَنَسٍ، عَنِ ابْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، قَالَ تَمَارَى رَجُلاَنِ فِي الْمَسْجِدِ الَّذِي أُسِّسَ عَلَى التَّقْوَى مِنْ أَوَّلِ يَوْمٍ فَقَالَ رَجُلٌ هُوَ مَسْجِدُ قُبَاءٍ وَقَالَ الآخَرُ هُوَ مَسْجِدُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هُوَ مَسْجِدِي هَذَا ‏"‏ ‏.‏\hadithno{697}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn Abi Sa'eed Al-Khudri that his father said:"Two men argued about the Masjid which was founded on piety from the first day. [1] One man said that it was the Masjid of Quba', and the other said that it was the Masjid of the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) said: 'It is this Masjid of mine.'" [1] At-Tawbah 9:}}
\hadithdefcmd{nasai}{698}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْتِي قُبَاءً رَاكِبًا وَمَاشِيًا ‏.‏\hadithno{698}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah (ﷺ) used to come to Quba' riding and walking." [1] Quba' is about three miles to the south of the Prophet's Masjid. This area is named after in that district}}
\hadithdefcmd{nasai}{699}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مُجَمِّعُ بْنُ يَعْقُوبَ، عَنْ مُحَمَّدِ بْنِ سُلَيْمَانَ الْكِرْمَانِيِّ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ بْنَ سَهْلِ بْنِ حُنَيْفٍ، قَالَ قَالَ أَبِي قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ خَرَجَ حَتَّى يَأْتِيَ هَذَا الْمَسْجِدَ مَسْجِدَ قُبَاءٍ فَصَلَّى فِيهِ كَانَ لَهُ عِدْلَ عُمْرَةٍ ‏"‏ ‏.‏\hadithno{699}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Umamah bin Sahl bin Hunaif said:"My father said: 'The Messenger of Allah (ﷺ) said: 'Whoever goes out to his Masjid - the Masjid of Quba' and prays therein, that will be equivalent to 'Umrah}}
\hadithdefcmd{nasai}{700}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُشَدُّ الرِّحَالُ إِلاَّ إِلَى ثَلاَثَةِ مَسَاجِدَ مَسْجِدِ الْحَرَامِ وَمَسْجِدِي هَذَا وَمَسْجِدِ الأَقْصَى ‏"‏ ‏.‏\hadithno{700}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Mounts are not saddled for except to (travel to) three Masjids: Al-Masjid Al-Haram, this Masjid of mine, and Al-Masjid Al-Aqsa}}
\hadithdefcmd{nasai}{701}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ مُلاَزِمٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بَدْرٍ، عَنْ قَيْسِ بْنِ طَلْقٍ، عَنْ أَبِيهِ، طَلْقِ بْنِ عَلِيٍّ قَالَ خَرَجْنَا وَفْدًا إِلَى النَّبِيِّ صلى الله عليه وسلم فَبَايَعْنَاهُ وَصَلَّيْنَا مَعَهُ وَأَخْبَرْنَاهُ أَنَّ بِأَرْضِنَا بِيعَةً لَنَا فَاسْتَوْهَبْنَاهُ مِنْ فَضْلِ طَهُورِهِ فَدَعَا بِمَاءٍ فَتَوَضَّأَ وَتَمَضْمَضَ ثُمَّ صَبَّهُ فِي إِدَاوَةٍ وَأَمَرَنَا فَقَالَ ‏"‏ اخْرُجُوا فَإِذَا أَتَيْتُمْ أَرْضَكُمْ فَاكْسِرُوا بِيعَتَكُمْ وَانْضَحُوا مَكَانَهَا بِهَذَا الْمَاءِ وَاتَّخِذُوهَا مَسْجِدًا ‏"‏ ‏.‏ قُلْنَا إِنَّ الْبَلَدَ بَعِيدٌ وَالْحَرَّ شَدِيدٌ وَالْمَاءَ يَنْشَفُ ‏.‏ فَقَالَ ‏"‏ مُدُّوهُ مِنَ الْمَاءِ فَإِنَّهُ لاَ يَزِيدُهُ إِلاَّ طِيبًا ‏"‏ ‏.‏ فَخَرَجْنَا حَتَّى قَدِمْنَا بَلَدَنَا فَكَسَرْنَا بِيعَتَنَا ثُمَّ نَضَحْنَا مَكَانَهَا وَاتَّخَذْنَاهَا مَسْجِدًا فَنَادَيْنَا فِيهِ بِالأَذَانِ ‏.‏ قَالَ وَالرَّاهِبُ رَجُلٌ مِنْ طَيِّئٍ فَلَمَّا سَمِعَ الأَذَانَ قَالَ دَعْوَةُ حَقٍّ ‏.‏ ثُمَّ اسْتَقْبَلَ تَلْعَةً مِنْ تِلاَعِنَا فَلَمْ نَرَهُ بَعْدُ ‏.‏\hadithno{701}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Talq bin 'Ali said:"We went out as a delegation to the Prophet (ﷺ); we gave him our oath of allegiance and prayed with him. We told him that in our land there was a church that belonged to us. We asked him to give us the leftovers of his purification (Wudu' water). So he called for water, performed Wudu' and rinsed out his mouth, then he poured it into a vessel and said to us: 'Leave, and when you return to your land, demolish your church, and sprinkle this water on that place, and take it as a Masjid.' We said: 'Our land is far away and it is very hot; the water is far away and it is very hot; the water will dry up.' He said: 'Add more water to it, for that will only make it better.' So we left and when we came to our land we demolished our church, then we sprinkled the water on that place and took it as a Masjid, and we called the Adhan in it. The monk was a man from Tayy', and when he heard the Adhan, he said: 'It is a true call.' Then he headed toward one of the hills and we never saw him again}}
\hadithdefcmd{nasai}{702}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَزَلَ فِي عُرْضِ الْمَدِينَةِ فِي حَىٍّ يُقَالُ لَهُمْ بَنُو عَمْرِو بْنِ عَوْفٍ فَأَقَامَ فِيهِمْ أَرْبَعَ عَشْرَةَ لَيْلَةً ثُمَّ أَرْسَلَ إِلَى مَلإٍ مِنْ بَنِي النَّجَّارِ فَجَاءُوا مُتَقَلِّدِي سُيُوفِهِمْ كَأَنِّي أَنْظُرُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى رَاحِلَتِهِ وَأَبُو بَكْرٍ - رضى الله عنه - رَدِيفُهُ وَمَلأٌ مِنْ بَنِي النَّجَّارِ حَوْلَهُ حَتَّى أَلْقَى بِفِنَاءِ أَبِي أَيُّوبَ وَكَانَ يُصَلِّي حَيْثُ أَدْرَكَتْهُ الصَّلاَةُ فَيُصَلِّي فِي مَرَابِضِ الْغَنَمِ ثُمَّ أُمِرَ بِالْمَسْجِدِ فَأَرْسَلَ إِلَى مَلإٍ مِنْ بَنِي النَّجَّارِ فَجَاءُوا فَقَالَ ‏ "‏ يَا بَنِي النَّجَّارِ ثَامِنُونِي بِحَائِطِكُمْ هَذَا ‏"‏ ‏.‏ قَالُوا وَاللَّهُ لاَ نَطْلُبُ ثَمَنَهُ إِلاَّ إِلَى اللَّهِ عَزَّ وَجَلَّ ‏.‏ قَالَ أَنَسٌ وَكَانَتْ فِيهِ قُبُورُ الْمُشْرِكِينَ وَكَانَتْ فِيهِ خَرِبٌ وَكَانَ فِيهِ نَخْلٌ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقُبُورِ الْمُشْرِكِينَ فَنُبِشَتْ وَبِالنَّخْلِ فَقُطِعَتْ وَبِالْخَرِبِ فَسُوِّيَتْ فَصَفُّوا النَّخْلَ قِبْلَةَ الْمَسْجِدِ وَجَعَلُوا عِضَادَتَيْهِ الْحِجَارَةَ وَجَعَلُوا يَنْقُلُونَ الصَّخْرَ وَهُمْ يَرْتَجِزُونَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم مَعَهُمْ وَهُمْ يَقُولُونَ اللَّهُمَّ لاَ خَيْرَ إِلاَّ خَيْرُ الآخِرَةِ فَانْصُرِ الأَنْصَارَ وَالْمُهَاجِرَةَ\hadithno{702}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:"When the Messenger of Allah (ﷺ) came to Al-Madinah, he alighted in the upper part of Al-Madinah among the tribe called Banu 'Amr bin 'Awf and he stayed with them for fourteen nights. Then he sent for the chiefs of Banu An-Najjar, and they came with their swords by their sides. It is as if I can see the Messenger of Allah (ﷺ) on his she-camel with Abu Bakr riding behind him (on the same camel) and the chiefs of Banu An-Najjar around him, until he dismounted in the courtyard of Abu Ayyub. The Prophet (ﷺ) used to offer the prayer wherever he was when the time for prayer came, and he would pray even in sheepfolds. Then he ordered that the Masjid be built. He sent for the chiefs of Banu An-Najjar, and when they came, he said: 'O Banu An-Najjar, name me a price for this grove of yours.' They said: 'By Allah, we will not ask for its price except from Allah.'" Anas said: "In (that grove) there were graves of idolators, ruins and date-palm trees. The Messenger of Allah (ﷺ) ordered that the graves of the idolators be dug up, the ruins be leveled and the date-palm trees be cut down. The trunks of the trees were arranged so as to form the walls facing the Qiblah. The stone pillars were built at the sides of its gate. They started to move the stones, reciting some lines of verse, and the Messenger of Allah (ﷺ) was with them when they were saying: 'O Allah! There is no good except the good of the Hereafter. So bestow victory on the Ansar and the Muhajirin}}
\hadithdefcmd{nasai}{703}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، وَيُونُسَ، قَالاَ قَالَ الزُّهْرِيُّ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، أَنَّ عَائِشَةَ، وَابْنَ، عَبَّاسٍ قَالاَ لَمَّا نُزِلَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم فَطَفِقَ يَطْرَحُ خَمِيصَةً لَهُ عَلَى وَجْهِهِ فَإِذَا اغْتَمَّ كَشَفَهَا عَنْ وَجْهِهِ قَالَ وَهُوَ كَذَلِكَ ‏ "‏ لَعْنَةُ اللَّهِ عَلَى الْيَهُودِ وَالنَّصَارَى اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏ ‏.‏\hadithno{703}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ubaidullah bin 'Abdullah reported that 'Aishah and Ibn 'Abbas said:"When the Messenger of Allah (ﷺ) was on his deathbed, he had a Khamisah over his face. When his temperature rose, he would uncover his face. When his temperature rose, he would uncover his face. While he was like that he said: 'May Allah curse the Jews and Christians, for they took the graves of their Prophets as places of worship}}
\hadithdefcmd{nasai}{704}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَائِشَةَ، أَنَّ أُمَّ حَبِيبَةَ، وَأُمَّ سَلَمَةَ ذَكَرَتَا كَنِيسَةً رَأَتَاهَا بِالْحَبَشَةِ فِيهَا تَصَاوِيرُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أُولَئِكَ إِذَا كَانَ فِيهِمُ الرَّجُلُ الصَّالِحُ فَمَاتَ بَنَوْا عَلَى قَبْرِهِ مَسْجِدًا وَصَوَّرُوا تِيكَ الصُّوَرَ أُولَئِكَ شِرَارُ الْخَلْقِ عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{704}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that Umm Habibah and Umm Salamah mentioned a church that they had seen in Ethiopia, in which there were images. The Messenger of Allah (ﷺ) said:"Those people, if there was a righteous man among them, when he died they built a place of worship over his grave and made those images. They will be the most evil of creation before Allah on the Day of Resurrection}}
\hadithdefcmd{nasai}{705}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، قَالَ حَدَّثَنَا الأَسْوَدُ بْنُ الْعَلاَءِ بْنِ جَارِيَةَ الثَّقَفِيُّ، عَنْ أَبِي سَلَمَةَ، - هُوَ ابْنُ عَبْدِ الرَّحْمَنِ - عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ حِينَ يَخْرُجُ الرَّجُلُ مِنْ بَيْتِهِ إِلَى مَسْجِدِهِ فَرِجْلٌ تُكْتَبُ حَسَنَةً وَرِجْلٌ تَمْحُو سَيِّئَةً ‏"‏ ‏.‏\hadithno{705}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"When a man goes out of his house to his Masjid, one foot records a good deed and the other erases a bad deed}}
\hadithdefcmd{nasai}{706}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا اسْتَأْذَنَتِ امْرَأَةُ أَحَدِكُمْ إِلَى الْمَسْجِدِ فَلاَ يَمْنَعْهَا ‏"‏ ‏.‏\hadithno{706}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim that his father said:"The Messenger of Allah (ﷺ) said: 'When the wife of any one of you asks for permission to go to the Masjid, do not stop her}}
\hadithdefcmd{nasai}{707}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، قَالَ حَدَّثَنَا عَطَاءٌ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ ‏"‏ ‏.‏ قَالَ أَوَّلَ يَوْمٍ ‏"‏ الثُّومِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ الثُّومِ وَالْبَصَلِ وَالْكُرَّاثِ فَلاَ يَقْرَبْنَا فِي مَسَاجِدِنَا فَإِنَّ الْمَلاَئِكَةَ تَتَأَذَّى مِمَّا يَتَأَذَّى مِنْهُ الإِنْسُ ‏"‏ ‏.‏\hadithno{707}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah (ﷺ) said: 'Whoever eats of this plant' - the first time he said 'garlic' then he said, 'garlic, onions and leeks' [1] - 'let him not approach us in our Masjids, for the angels are offended by that which offends mankinds.'" [1] In Fath, Al-Bari, Ibn Hajar is of the opinion that it was Ibn Juraij who was talking, explaining that 'Ata' - who reported it from Jabir - narrated it both ways}}
\hadithdefcmd{nasai}{708}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ إِنَّكُمْ أَيُّهَا النَّاسُ تَأْكُلُونَ مِنْ شَجَرَتَيْنِ مَا أُرَاهُمَا إِلاَّ خَبِيثَتَيْنِ هَذَا الْبَصَلُ وَالثُّومُ وَلَقَدْ رَأَيْتُ نَبِيَّ اللَّهِ صلى الله عليه وسلم إِذَا وَجَدَ رِيحَهُمَا مِنَ الرَّجُلِ أَمَرَ بِهِ فَأُخْرِجَ إِلَى الْبَقِيعِ فَمَنْ أَكَلَهُمَا فَلْيُمِتْهُمَا طَبْخًا ‏.‏\hadithno{708}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ma'dam bin Abi Talhah that 'Umar bin Al-Khattab said:"O people, you eat of two plants which I do not think are anything but bad, this onion and garlic. I have seen the Prophet of Allah (ﷺ), if he noticed their smell coming from a man, ordering that he be taken out to Al-Baqi'. Whoever eats them, let him cook them to death}}
\hadithdefcmd{nasai}{709}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْلَى، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَعْتَكِفَ صَلَّى الصُّبْحَ ثُمَّ دَخَلَ فِي الْمَكَانِ الَّذِي يُرِيدُ أَنْ يَعْتَكِفَ فِيهِ فَأَرَادَ أَنْ يَعْتَكِفَ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ فَأَمَرَ فَضُرِبَ لَهُ خِبَاءٌ وَأَمَرَتْ حَفْصَةُ فَضُرِبَ لَهَا خِبَاءٌ فَلَمَّا رَأَتْ زَيْنَبُ خِبَاءَهَا أَمَرَتْ فَضُرِبَ لَهَا خِبَاءٌ فَلَمَّا رَأَى ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ آلْبِرَّ تُرِدْنَ ‏"‏ ‏.‏ فَلَمْ يَعْتَكِفْ فِي رَمَضَانَ وَاعْتَكَفَ عَشْرًا مِنْ شَوَّالٍ ‏.‏\hadithno{709}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"When the Messenger of Allah (ﷺ) wanted to observe I'tikaf, [2] he would pray Fajr then enter the place where he wnated to observe I'tikaf. He wanted to observe I'tikaf during the last ten days of Ramadan, so he commanded that a Khiba' (tent) be pitched for him. Then Hafsah ordered that a Khiba' be pitched for her, and when Zainab saw her tent she ordered that a Khiba' be pitched for her too. When the Messenger of Allah (ﷺ) saw that he said: 'Is it righteousness that you seek?' And he did not observe I'tikaf in Ramadan, and observed I'tikaf for ten days in Shawwal (instead)." [1] Al-Khiba': "One of the house of the Bedouins made of Wabir (camel or goat fur) or wool, not of hair (from other pelts). And it would have two or three posts." (An-Nihayah) [2] Seclusion in the Masjid for the sake of devotion to Allah}}
\hadithdefcmd{nasai}{710}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أُصِيبَ سَعْدٌ يَوْمَ الْخَنْدَقِ رَمَاهُ رَجُلٌ مِنْ قُرَيْشٍ رَمْيَةً فِي الأَكْحَلِ فَضَرَبَ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْمَةً فِي الْمَسْجِدِ لِيَعُودَهُ مِنْ قَرِيبٍ ‏.‏\hadithno{710}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"Sa'd was wounded on the day of Al-Khandaq [1] when a man of Quraish shot him in the medial arm vein. The Messenger of Allah (ﷺ) pitched a tent (Khaimah) for him in the Masjid so that he could visit him close at hand." [1] Al-Khandaq means the trench. This indicates the battle of the trench which took place during the fifth year after Hijrah}}
\hadithdefcmd{nasai}{711}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، أَنَّهُ سَمِعَ أَبَا قَتَادَةَ، يَقُولُ بَيْنَا نَحْنُ جُلُوسٌ فِي الْمَسْجِدِ إِذْ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَحْمِلُ أُمَامَةَ بِنْتَ أَبِي الْعَاصِ بْنِ الرَّبِيعِ وَأُمُّهَا زَيْنَبُ بِنْتُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهِيَ صَبِيَّةٌ يَحْمِلُهَا فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم وَهِيَ عَلَى عَاتِقِهِ يَضَعُهَا إِذَا رَكَعَ وَيُعِيدُهَا إِذَا قَامَ حَتَّى قَضَى صَلاَتَهُ يَفْعَلُ ذَلِكَ بِهَا ‏.‏\hadithno{711}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Amr bin Sulaim Az-Zuraqi that he heard Abu Qatadah say:"While we were sitting in the Masjid. The Messenger of Allah (ﷺ) came out to us carrying Umamah bint Abi Al-'As bin Ar-Rabi', whose mother was Zainab, the daughter of the Messenger of Allah (ﷺ). She was a little girl and he was carrying her. The Messenger of Allah (ﷺ) prayed with her on his shoulder, putting her down when he bowed and picking her up again when he stood up, until he completed his prayer}}
\hadithdefcmd{nasai}{712}{أَخْبَرَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْلاً قِبَلَ نَجْدٍ فَجَاءَتْ بِرَجُلٍ مِنْ بَنِي حَنِيفَةَ يُقَالُ لَهُ ثُمَامَةُ بْنُ أُثَالٍ سَيِّدُ أَهْلِ الْيَمَامَةِ فَرُبِطَ بِسَارِيَةٍ مِنْ سَوَارِي الْمَسْجِدِ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{712}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Sa'eed bin Abi Sa'eed that he heard Abu Hurairah say:"The Messenger of Allah (ﷺ) sent some horsemen toward Najd, and they brought back a man from Banu Hanifah who was called Thumamah bin Uthal, the chief of the people of Al-Yamamah. Then he was tied to one of the pillars of the Masjid}}
\hadithdefcmd{nasai}{713}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَافَ فِي حَجَّةِ الْوَدَاعِ عَلَى بَعِيرٍ يَسْتَلِمُ الرُّكْنَ بِمِحْجَنٍ ‏.‏\hadithno{713}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Abbas that the Messenger of Allah (ﷺ) performed Tawaf during the Farewell Pilgrimage atop a camel, touching the Rukn [1] with a stick that was bent at the top. [1] The corner of the Ka'bah in which the Black Stone is situated}}
\hadithdefcmd{nasai}{714}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَخْبَرَنِي يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ التَّحَلُّقِ يَوْمَ الْجُمُعَةِ قَبْلَ الصَّلاَةِ وَعَنِ الشِّرَاءِ وَالْبَيْعِ فِي الْمَسْجِدِ ‏.‏\hadithno{714}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather, that the Prophet (ﷺ) forbade sitting in circles on Friday before Jumu'ah prayer, and buying and selling in the Masjid}}
\hadithdefcmd{nasai}{715}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ تَنَاشُدِ الأَشْعَارِ فِي الْمَسْجِدِ ‏.‏\hadithno{715}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather, that the Prophet (ﷺ) forbade reciting poetry in the Masjid}}
\hadithdefcmd{nasai}{716}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ مَرَّ عُمَرُ بِحَسَّانَ بْنِ ثَابِتٍ وَهُوَ يُنْشِدُ فِي الْمَسْجِدِ فَلَحَظَ إِلَيْهِ فَقَالَ قَدْ أَنْشَدْتُ وَفِيهِ مَنْ هُوَ خَيْرٌ مِنْكَ ثُمَّ الْتَفَتَ إِلَى أَبِي هُرَيْرَةَ فَقَالَ أَسَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَجِبْ عَنِّي اللَّهُمَّ أَيِّدْهُ بِرُوحِ الْقُدُسِ ‏"‏ ‏.‏ قَالَ اللَّهُمَّ نَعَمْ ‏.‏\hadithno{716}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Sa'eed bin Al-Musayyab said:"Umar passed by Hassan bin Thabit while he was reciting poetry in the Masjid, and glared at him. He said: 'I recited poetry when there was someone better than you in the Masjid.' Then he turned to Abu Hurairah and said: 'Did you not hear the Messenger of Allah (ﷺ) when he said: "Answer back on my behalf. O Allah, help him with the Holy Spirit!'" He said: 'Yes, by Allah}}
\hadithdefcmd{nasai}{717}{أَخْبَرَنَا مُحَمَّدُ بْنُ وَهْبٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ أَبِي عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنِي زَيْدُ بْنُ أَبِي أُنَيْسَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ جَاءَ رَجُلٌ يَنْشُدُ ضَالَّةً فِي الْمَسْجِدِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ وَجَدْتَ ‏"‏ ‏.‏\hadithno{717}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"A man came making announcement of a lost camel in the Masjid, and the Messenger of Allah (ﷺ) said: 'May you never find it}}
\hadithdefcmd{nasai}{718}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْمِسْوَرِ الزُّهْرِيُّ، - بَصْرِيٌّ - وَمُحَمَّدُ بْنُ مَنْصُورٍ قَالاَ حَدَّثَنَا سُفْيَانُ، قَالَ قُلْتُ لِعَمْرٍو أَسَمِعْتَ جَابِرًا يَقُولُ مَرَّ رَجُلٌ بِسِهَامٍ فِي الْمَسْجِدِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خُذْ بِنِصَالِهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏\hadithno{718}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sufyan said:"I said to 'Amr: 'Did you hear Jabir say: "A man passed through the Masjid carrying arrows, and the Messenger of Allah (ﷺ) said to him: 'Hold then by the blades.'? He said: 'Yes}}
\hadithdefcmd{nasai}{719}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عِيسَى بْنُ يُونُسَ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، قَالَ دَخَلْتُ أَنَا وَعَلْقَمَةُ، عَلَى عَبْدِ اللَّهِ بْنِ مَسْعُودٍ فَقَالَ لَنَا أَصَلَّى هَؤُلاَءِ قُلْنَا لاَ ‏.‏ قَالَ قُومُوا فَصَلُّوا ‏.‏ فَذَهَبْنَا لِنَقُومَ خَلْفَهُ فَجَعَلَ أَحَدَنَا عَنْ يَمِينِهِ وَالآخَرَ عَنْ شِمَالِهِ فَصَلَّى بِغَيْرِ أَذَانٍ وَلاَ إِقَامَةٍ فَجَعَلَ إِذَا رَكَعَ شَبَّكَ بَيْنَ أَصَابِعِهِ وَجَعَلَهَا بَيْنَ رُكْبَتَيْهِ وَقَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَعَلَ ‏.‏\hadithno{719}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Al-Aswad said:"Alqamah and I entered upon 'Abdullah bin Mas'ud and he said to us: 'Have these people prayed?' We said: 'No.' He said: 'Get up and pray.' So we went to stand behind him, and he put one of us on his right and the other on his left, and he prayed with no Adhan and no Iqamah. When he bowed he interlaced his fingers and placed his hands between his knees, and he said: 'I saw the Messenger of Allah (ﷺ) doing that}}
\hadithdefcmd{nasai}{720}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا النَّضْرُ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، قَالَ سَمِعْتُ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{720}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sulaiman said:"I heard Ibrahim (narrate) from 'Alqamah and Al-Aswad from 'Abdullah," and he narrated something similar}}
\hadithdefcmd{nasai}{721}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم مُسْتَلْقِيًا فِي الْمَسْجِدِ وَاضِعًا إِحْدَى رِجْلَيْهِ عَلَى الأُخْرَى ‏.‏\hadithno{721}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abbad bin Tamim, from his paternal uncle, that he saw the messenger of Allah (ﷺ) lying on his back in the Masjid, placing one leg on top of the other}}
\hadithdefcmd{nasai}{722}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ يَنَامُ وَهُوَ شَابٌّ عَزْبٌ لاَ أَهْلَ لَهُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي مَسْجِدِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{722}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar, that when he was young and single, with no family, at the time of the Messenger of Allah (ﷺ), he used to sleep in the Masjid of the Prophet (ﷺ)}}
\hadithdefcmd{nasai}{723}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبُصَاقُ فِي الْمَسْجِدِ خَطِيئَةٌ وَكَفَّارَتُهَا دَفْنُهَا ‏"‏ ‏.‏\hadithno{723}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ) said: 'Spitting in the Masjid is a sin, and its expiation is to bury it}}
\hadithdefcmd{nasai}{724}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى بُصَاقًا فِي جِدَارِ الْقِبْلَةِ فَحَكَّهُ ثُمَّ أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏ "‏ إِذَا كَانَ أَحَدُكُمْ يُصَلِّي فَلاَ يَبْصُقَنَّ قِبَلَ وَجْهِهِ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ قِبَلَ وَجْهِهِ إِذَا صَلَّى ‏"‏ ‏.‏\hadithno{724}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) saw some sputum on the Qiblah wall. He scrapped it off then he turned to the people and said:"When any one of you is praying, let him not spit in front of him, for Allah is in front of him when he prays}}
\hadithdefcmd{nasai}{725}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى نُخَامَةً فِي قِبْلَةِ الْمَسْجِدِ فَحَكَّهَا بِحَصَاةٍ وَنَهَى أَنْ يَبْصُقَ الرَّجُلُ بَيْنَ يَدَيْهِ أَوْ عَنْ يَمِينِهِ وَقَالَ ‏ "‏ يَبْصُقُ عَنْ يَسَارِهِ أَوْ تَحْتَ قَدَمِهِ الْيُسْرَى ‏"‏ ‏.‏\hadithno{725}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that the Prophet (ﷺ) saw some spittle in the Qiblah of the Masjid. He scratched it off with a pebble and forbade a man to spit to his front or to his right. He said:"Let him spit to his left or beneath his left foot}}
\hadithdefcmd{nasai}{726}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي مَنْصُورٌ، عَنْ رِبْعِيٍّ، عَنْ طَارِقِ بْنِ عَبْدِ اللَّهِ الْمُحَارِبِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كُنْتَ تُصَلِّي فَلاَ تَبْزُقَنَّ بَيْنَ يَدَيْكَ وَلاَ عَنْ يَمِينِكَ وَابْصُقْ خَلْفَكَ أَوْ تِلْقَاءَ شِمَالِكَ إِنْ كَانَ فَارِغًا وَإِلاَّ فَهَكَذَا ‏"‏ ‏.‏ وَبَزَقَ تَحْتَ رِجْلِهِ وَدَلَكَهُ ‏.‏\hadithno{726}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Tariq bin 'Abdullah Al-Muharibi said:'When you are praying, do not spit to the front or to your right. Spit behind you or to your left if there is no one there, otherwise do this.' And he spat beneath his foot and rubbed it}}
\hadithdefcmd{nasai}{727}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، عَنْ أَبِي الْعَلاَءِ بْنِ الشِّخِّيرِ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَنَخَّعَ فَدَلَكَهُ بِرِجْلِهِ الْيُسْرَى ‏.‏\hadithno{727}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Al-'Ala' bin Ash-Shikhir that his father said:"I saw the Messenger of Allah (ﷺ) spit and then rub it with his left foot}}
\hadithdefcmd{nasai}{728}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَائِذُ بْنُ حَبِيبٍ، قَالَ حَدَّثَنَا حُمَيْدٌ الطَّوِيلُ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم نُخَامَةً فِي قِبْلَةِ الْمَسْجِدِ فَغَضِبَ حَتَّى احْمَرَّ وَجْهُهُ فَقَامَتِ امْرَأَةٌ مِنَ الأَنْصَارِ فَحَكَّتْهَا وَجَعَلَتْ مَكَانَهَا خَلُوقًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أَحْسَنَ هَذَا ‏"‏ ‏.‏\hadithno{728}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah (ﷺ) saw some sputum in the Qiblah of the Masjid, and he became so angry that his face turned red. Then a woman from the Ansar went and scratched off, and put some perfume in its place. The Messenger of Allah (ﷺ) said: 'How good this is}}
\hadithdefcmd{nasai}{729}{أَخْبَرَنَا سُلَيْمَانُ بْنُ عُبَيْدِ اللَّهِ الْغَيْلاَنِيُّ، - بَصْرِيٌّ - قَالَ حَدَّثَنَا أَبُو عَامِرٍ، قَالَ حَدَّثَنَا سُلَيْمَانُ، عَنْ رَبِيعَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ سَعِيدٍ، قَالَ سَمِعْتُ أَبَا حُمَيْدٍ، وَأَبَا، أُسَيْدٍ يَقُولاَنِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَخَلَ أَحَدُكُمُ الْمَسْجِدَ فَلْيَقُلِ اللَّهُمَّ افْتَحْ لِي أَبْوَابَ رَحْمَتِكَ وَإِذَا خَرَجَ فَلْيَقُلِ اللَّهُمَّ إِنِّي أَسْأَلُكَ مِنْ فَضْلِكَ ‏"‏ ‏.‏\hadithno{729}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdul-Malik bin Sa'eed said:"I heard Abu Humaid and Abu Usaid say: 'The Messenger of Allah (ﷺ) said: "When any one of you enters the Masjid, let him say: 'Allahumma aftahli abwaba rahmatik (O Allah, open to me the gates of your mercy). And when he leaves let him say: Allahumma inni as'aluka min fadlik (O Allah, I ask You of Your bounty)}}
\hadithdefcmd{nasai}{730}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَمْرِو بْنِ سُلَيْمِ، عَنْ أَبِي قَتَادَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دَخَلَ أَحَدُكُمُ الْمَسْجِدَ فَلْيَرْكَعْ رَكْعَتَيْنِ قَبْلَ أَنْ يَجْلِسَ ‏"‏ ‏.‏\hadithno{730}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Qatadah that the Messenger of Allah (ﷺ) said:"When any one of you enters the Masjid, let him pray two Rak'ahs before he sits down}}
\hadithdefcmd{nasai}{731}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، قَالَ ابْنُ شِهَابٍ وَأَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ كَعْبِ بْنِ مَالِكٍ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبٍ، قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ، يُحَدِّثُ حَدِيثَهُ حِينَ تَخَلَّفَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ قَالَ وَصَبَّحَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَادِمًا وَكَانَ إِذَا قَدِمَ مِنْ سَفَرٍ بَدَأَ بِالْمَسْجِدِ فَرَكَعَ فِيهِ رَكْعَتَيْنِ ثُمَّ جَلَسَ لِلنَّاسِ فَلَمَّا فَعَلَ ذَلِكَ جَاءَهُ الْمُخَلَّفُونَ فَطَفِقُوا يَعْتَذِرُونَ إِلَيْهِ وَيَحْلِفُونَ لَهُ وَكَانُوا بِضْعًا وَثَمَانِينَ رَجُلاً فَقَبِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلاَنِيَتَهُمْ وَبَايَعَهُمْ وَاسْتَغْفَرَ لَهُمْ وَوَكَلَ سَرَائِرَهُمْ إِلَى اللَّهِ عَزَّ وَجَلَّ حَتَّى جِئْتُ فَلَمَّا سَلَّمْتُ تَبَسَّمَ تَبَسُّمَ الْمُغْضَبِ ثُمَّ قَالَ ‏"‏ تَعَالَ ‏"‏ ‏.‏ فَجِئْتُ حَتَّى جَلَسْتُ بَيْنَ يَدَيْهِ فَقَالَ لِي ‏"‏ مَا خَلَّفَكَ أَلَمْ تَكُنِ ابْتَعْتَ ظَهْرَكَ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي وَاللَّهِ لَوْ جَلَسْتُ عِنْدَ غَيْرِكَ مِنْ أَهْلِ الدُّنْيَا لَرَأَيْتُ أَنِّي سَأَخْرُجُ مِنْ سَخَطِهِ وَلَقَدْ أُعْطِيتُ جَدَلاً وَلَكِنْ وَاللَّهِ لَقَدْ عَلِمْتُ لَئِنْ حَدَّثْتُكَ الْيَوْمَ حَدِيثَ كَذِبٍ لِتَرْضَى بِهِ عَنِّي لَيُوشَكُ أَنَّ اللَّهَ عَزَّ وَجَلَّ يُسْخِطُكَ عَلَىَّ وَلَئِنْ حَدَّثْتُكَ حَدِيثَ صِدْقٍ تَجِدُ عَلَىَّ فِيهِ إِنِّي لأَرْجُو فِيهِ عَفْوَ اللَّهِ وَاللَّهِ مَا كُنْتُ قَطُّ أَقْوَى وَلاَ أَيْسَرَ مِنِّي حِينَ تَخَلَّفْتُ عَنْكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَّا هَذَا فَقَدْ صَدَقَ فَقُمْ حَتَّى يَقْضِيَ اللَّهُ فِيكَ ‏"‏ ‏.‏ فَقُمْتُ فَمَضَيْتُ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{731}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Ka'b said:"I heard Ka'b bin Malik telling the story of when he stayed behind from going out on the campaign of Tabuk with the Messenger of Allah (ﷺ). He said: 'The Messenger of Allah (ﷺ) came back in the morning, and when he came back from a journey he would go to the Masjid first and pray two Rak'ahs there, then he would sit to (meet with) the people. When he did that, those who had stayed behind came to him and started giving their excuses, swearing by Allah. There were eighty-odd men, and the Messenger of Allah (ﷺ) accepted what they declared and accepted their oaths of allegiance; he prayed for forgiveness for them and left whatever was in their hearts to Allah. Then when I came and greeted him, he smiled as one who is angry, then he said: 'Come here.' So I came and sat in front of him, [1] and he said: 'What kept you behind? Did you not buy a mount?' I said: 'O Messenger of Allah, if I were to sit before anyone other than you of those who hold high positions in this world, I would find a way to avoid his anger. I am an eloquent man but, by Allah, I know that if I were to tell you a lie today to make you pleased with me, Allah would soon make you angry with me, but if I tell you the truth, it will make you angry with me, but I will still have the hope that Allah may forgive me. I have never been in a better position, physically or financially, than the time when I stayed behind and did not join you.' The Messenger of Allah (ﷺ) said: 'This man has spoken the truth. Go away until Allah decides concerning you.' So I got up and went away." This is an abridged version of narration. [1] It is this which the author cited the narration for. While the absence of the mention of a thing - in this case prayer - is not a proof that it does not exist}}
\hadithdefcmd{nasai}{732}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ بْنِ أَعْيَنَ، قَالَ حَدَّثَنَا شُعَيْبٌ، قَالَ حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنَا خَالِدٌ، عَنِ ابْنِ أَبِي هِلاَلٍ، قَالَ أَخْبَرَنِي مَرْوَانُ بْنُ عُثْمَانَ، أَنَّ عُبَيْدَ بْنَ حُنَيْنٍ، أَخْبَرَهُ عَنْ أَبِي سَعِيدِ بْنِ الْمُعَلَّى، قَالَ كُنَّا نَغْدُو إِلَى السُّوقِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنَمُرُّ عَلَى الْمَسْجِدِ فَنُصَلِّي فِيهِ ‏.‏\hadithno{732}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa'eed bin Al-Mu'alla said:"We used to go to the marketplace in the morning at the time of the Messenger of Allah (ﷺ), and we would pass through the Masjid and pray there}}
\hadithdefcmd{nasai}{733}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْمَلاَئِكَةَ تُصَلِّي عَلَى أَحَدِكُمْ مَا دَامَ فِي مُصَلاَّهُ الَّذِي صَلَّى فِيهِ مَا لَمْ يُحْدِثِ اللَّهُمَّ اغْفِرْ لَهُ اللَّهُمَّ ارْحَمْهُ ‏"‏ ‏.‏\hadithno{733}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"The angels send Salah upon any one of you so long as he is in the place where he prays, and so long as he does not invalidate his ablution, (saying): 'O Allah, forgive him, O Allah, have mercy on him}}
\hadithdefcmd{nasai}{734}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا بَكْرُ بْنُ مُضَرَ، عَنْ عَيَّاشِ بْنِ عُقْبَةَ، أَنَّ يَحْيَى بْنَ مَيْمُونٍ، حَدَّثَهُ قَالَ سَمِعْتُ سَهْلاً السَّاعِدِيَّ، - رضى الله عنه - يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ كَانَ فِي الْمَسْجِدِ يَنْتَظِرُ الصَّلاَةَ فَهُوَ فى الصَّلاَةِ ‏"‏ ‏.‏\hadithno{734}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sahl As-Sa'idi, may Allah be pleased with him, said:"I heard the Messenger of Allah (ﷺ) say: 'Whoever is in the Masjid waiting for the prayer, he is in a state of prayer}}
\hadithdefcmd{nasai}{735}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ أَشْعَثَ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الصَّلاَةِ فِي أَعْطَانِ الإِبِلِ ‏.‏\hadithno{735}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin Mughaffal that the Messenger of Allah (ﷺ) forbade praying in the camel pens. [1] A'tan:Kneeling places, or, where they kneel to drink water}}
\hadithdefcmd{nasai}{736}{أَخْبَرَنَا الْحَسَنُ بْنُ إِسْمَاعِيلَ بْنِ سُلَيْمَانَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ حَدَّثَنَا سَيَّارٌ، عَنْ يَزِيدَ الْفَقِيرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ جُعِلَتْ لِيَ الأَرْضُ مَسْجِدًا وَطَهُورًا أَيْنَمَا أَدْرَكَ رَجُلٌ مِنْ أُمَّتِي الصَّلاَةَ صَلَّى ‏"‏ ‏.‏\hadithno{736}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"The Messenger of Allah (ﷺ) said: 'The earth has been made for me a place of prostration and a means of purification, so wherever a man of my Ummah is when the time for prayer comes, let him pray}}
\hadithdefcmd{nasai}{737}{أَخْبَرَنَا سَعِيدُ بْنُ يَحْيَى بْنِ سَعِيدٍ الأُمَوِيُّ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ أُمَّ سُلَيْمٍ، سَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يَأْتِيَهَا فَيُصَلِّيَ فِي بَيْتِهَا فَتَتَّخِذَهُ مُصَلًّى فَأَتَاهَا فَعَمَدَتْ إِلَى حَصِيرٍ فَنَضَحَتْهُ بِمَاءٍ فَصَلَّى عَلَيْهِ وَصَلَّوْا مَعَهُ ‏.‏\hadithno{737}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas bin Malik that Umm Sulaim asked the Messenger of Allah (ﷺ) to come to her and pray in her house so that she could take (the place where he prayed) as a Musalla (prayer place). So he came to her and she went and got a reed mat and sprinkled it with water, and he prayed on it, and they prayed with him}}
\hadithdefcmd{nasai}{738}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، - يَعْنِي الشَّيْبَانِيَّ - عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنْ مَيْمُونَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي عَلَى الْخُمْرَةِ ‏.‏\hadithno{738}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Maimunah that the Messenger of Allah (ﷺ) used to pray on a mat}}
\hadithdefcmd{nasai}{739}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنِي أَبُو حَازِمِ بْنِ دِينَارٍ، أَنَّ رِجَالاً، أَتَوْا سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ وَقَدِ امْتَرَوْا فِي الْمِنْبَرِ مِمَّ عُودُهُ فَسَأَلُوهُ عَنْ ذَلِكَ فَقَالَ وَاللَّهِ إِنِّي لأَعْرِفُ مِمَّ هُوَ وَلَقَدْ رَأَيْتُهُ أَوَّلَ يَوْمٍ وُضِعَ وَأَوَّلَ يَوْمٍ جَلَسَ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى فُلاَنَةَ امْرَأَةٍ قَدْ سَمَّاهَا سَهْلٌ ‏"‏ أَنْ مُرِي غُلاَمَكِ النَّجَّارَ أَنْ يَعْمَلَ لِي أَعْوَادًا أَجْلِسُ عَلَيْهِنَّ إِذَا كَلَّمْتُ النَّاسَ ‏"‏ ‏.‏ فَأَمَرَتْهُ فَعَمِلَهَا مِنْ طَرْفَاءِ الْغَابَةِ ثُمَّ جَاءَ بِهَا فَأَرْسَلَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَ بِهَا فَوُضِعَتْ هَا هُنَا ثُمَّ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم رَقِيَ فَصَلَّى عَلَيْهَا وَكَبَّرَ وَهُوَ عَلَيْهَا ثُمَّ رَكَعَ وَهُوَ عَلَيْهَا ثُمَّ نَزَلَ الْقَهْقَرَى فَسَجَدَ فِي أَصْلِ الْمِنْبَرِ ثُمَّ عَادَ فَلَمَّا فَرَغَ أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏"‏ يَا أَيُّهَا النَّاسُ إِنَّمَا صَنَعْتُ هَذَا لِتَأْتَمُّوا بِي وَلِتَعَلَّمُوا صَلاَتِي ‏"‏ ‏.‏\hadithno{739}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hazim bin Dinar narrated that some men came to Sahl bin Sa'd As-Sa'idi. They were wondering what kind of wood the Minbar was made of, so they asked him about that. He said:"By Allah, I know what it is made of. I saw it the first day it was set up and the first day the Messenger of Allah (ﷺ) sat on it. The Messenger of Allah (ﷺ) sent word to so-and-so" - a woman whose name Sahl mentioned - "telling her: 'Tell your carpenter slave to make me something of wood that I can sit on when I speak to the people.' So she told him, and he made it from tamarisk wood from Al-Ghabah (a place near Al-Madinah). Then he brought it and it was sent to the Messenger of Allah (ﷺ), who commanded that it be set up here. Then I saw the Messenger of Allah (ﷺ) ascend it and praying on it, and saying the Takbir while he was on top of it, then he bowed when he was on top of it, then he came down backward and prostrated at the base of the Minbar, then he went back. When he had finished he turned to face the people and said: 'O people, I only did this so that you can follow me in prayer and learn how I pray}}
\hadithdefcmd{nasai}{740}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي عَلَى حِمَارٍ وَهُوَ مُتَوَجِّهٌ إِلَى خَيْبَرَ ‏.‏\hadithno{740}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Umar said:"I saw the Messenger of Allah (ﷺ) praying on a donkey, when he was heading toward Khaibar}}
\hadithdefcmd{nasai}{741}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا دَاوُدُ بْنُ قَيْسٍ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي عَلَى حِمَارٍ وَهُوَ رَاكِبٌ إِلَى خَيْبَرَ وَالْقِبْلَةُ خَلْفَهُ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ لاَ نَعْلَمُ أَحَدًا تَابَعَ عَمْرَو بْنَ يَحْيَى عَلَى قَوْلِهِ يُصَلِّي عَلَى حِمَارٍ وَحَدِيثُ يَحْيَى بْنِ سَعِيدٍ عَنْ أَنَسٍ الصَّوَابُ مَوْقُوفٌ وَاللَّهُ سُبْحَانَهُ وَتَعَالَى أَعْلَمُ ‏.‏\hadithno{741}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that he saw the Messenger of Allah (ﷺ) praying on a donkey while he was riding, praying toward Khaibar with the Qiblah behind him. Abu 'Abdur-Rahman (An-Nasa'i) said:We do not know of anyone who reported anything to support what 'Amr bin Yahya said about praying on a donkey. As for the Hadith of Yahya bin Sa'eed from Anas, what is correct is that it is Mawquf. [1] And Allah knows best. [1] That is a saying or action of a Companion of the Prophet (ﷺ)}}
